#!/usr/bin/python3
import json
import logging
import logging.config
from configparser import ConfigParser
import os

from bottle import run, request, get, put, HTTPResponse

serverHost = '127.0.0.1'
serverPort = 8080

servicePath = os.path.dirname(os.path.abspath(__file__))


@get('/onlinechecks/<id>')
def getOnlinecheck(id):
    '''
    Получение онлайн-чека по номеру из файла
    '''
    logging.info(u"Получен запрос на получение чека  %s" % id)
    filePath = os.path.join(servicePath, 'data/onlinecheck_%s.json' % id)
    if os.path.isfile(filePath):
        try:
            with open(filePath) as f:
                data = json.loads(f.read())
                logging.info(u"Онлайн-чек: %s" % data)
                return data
        except ValueError:
            '''
            если документ не прошел json-валидацию, то возвращаем какую-нибудь ошибку
            '''
            raise HTTPResponse(body='{"errorCode": 404, "url": "/CSrest/rest/dictionaries/onlinechecks/%s","message": "'
                                 'Некорректный формат документа с идентификатором %s.", "errorClassName": '
                                 '"OnlineCheckNotFoundException"}' % (id, id), status=404)
    else:
        '''
        если документа с указанным номером нет, то возвращаем соответсвующую ошибку
        '''
        data = HTTPResponse(body='{"errorCode": 404, "url": "/CSrest/rest/dictionaries/onlinechecks/%s","message": "'
                                 'Документ с идентификатором %s не найден.", "errorClassName": '
                                 '"OnlineCheckNotFoundException"}' % (id, id), status=404)
        logging.info(u"Ответ от сервера: %s" % data)
        raise data


@put('/onlinechecks/<id>')
def putOnlinecheck(id):
    '''
    Прием закрытого/отмененного чека с кассы
    '''
    data = json.loads(json.dumps(request.json))
    logging.info(u"Получен запрос: %s" % (data))
    result = {"status": 200}
    logging.info(u"Ответ от сервера: %s" % result)
    return json.dumps(result, ensure_ascii=False)


def readConfig():
    '''
    Чтение настроек из конфигурационного файла
    '''
    global serverHost, serverPort
    logging.info(u"Чтение настроек: ")
    config = ConfigParser()
    try:
        config.read(os.path.join(servicePath, 'config/conf.ini'))
        serverHost = config.get('OnlineCheck', 'host')
        serverPort = config.getint('OnlineCheck', 'port')
        logging.info(u"Хост: %s, Порт: %s" % (serverHost, str(serverPort)))
    except Exception as e:
        logging.info(u"Ошибка: %s . Будут применены настройки по умолчанию: адрес сервера: "
                     "127.0.0.1:8080" % e)
        print(u"Ошибка: %s . Будут применены настройки по умолчанию: адрес сервера: "
              u"127.0.0.1:8080" % e)


def startService():
    '''
    Старт сервиса
    '''

    logging.basicConfig(format=u'[%(asctime)s] %(levelname)s - %(message)s', level=logging.INFO,
                        filename=os.path.join(servicePath, u'onlinechecktest.log'))
    readConfig()
    try:
        run(host=serverHost, port=serverPort)
        logging.info(u"Запуск сервиса на %s:%s" % (serverHost, str(serverPort)))
    except Exception as e:
        print(u"Ошибка: %s" % e)


if __name__ == '__main__':
    startService()
